function y = uq_trussModelAnalytical(X)
% UQ_TRUSSMODELANALYTICAL computes the midspan deflection of a simply
% supported truss model under vertically oriented static loading located in
% all six upper chord nodes.
%
%  Model with ten input parameters X = [E1 E2 A1 A1 P1 P2 P3 P4 P5 P6]
%         E1:   Young's modulus
%         E2:   Young's modulus
%         A1:   Cross-sectional area
%         A2:   Cross-sectional area
%         P1:   vertical load
%         P2:   vertical load
%         P3:   vertical load
%         P4:   vertical load
%         P5:   vertical load
%         P6:   vertical load
%
%  Reference: 
%  - Blatman, G., Sudret, B. Adaptive sparse polynomial chaos
%    expansion based on least angle regression, Journal of computational
%    Physics, vol. 230, issue 6 pp.23452367, 2011.
%    DOI:10.1016/j.jcp.2010.12.021

%% Check inputs
%
narginchk(1,2)
assert(size(X,2)==10,'Only 10 input variables are allowed!')

%% Evaluate the function

E1 = X(:,1); E2 = X(:,2);               % Young's modulus
A1 = X(:,3); A2 = X(:,4);               % cross-sectional areas
P1 = X(:,5); P2 = X(:,6); P3 = X(:,7);  % loadings
P4 = X(:,8); P5 = X(:,9); P6 = X(:,10); % loadings

y = - (2*2^0.5.*A1.*P1 + 6*2^0.5.*A1.*P2 + 10*2^0.5.*A1.*P3 ...
    + 10*2^0.5.*A1.*P4 + 6.*2^0.5.*A1.*P5 + 2*2^0.5.*A1.*P6)./(A1.*A2.*E2) ...
    - (36.*A2.*E2.*P1 + 100.*A2.*E2.*P2 + 140.*A2.*E2.*P3 + 140.*A2.*E2.*P4 ...
    + 100.*A2.*E2.*P5 + 36.*A2.*E2.*P6)./(A1.*A2.*E1.*E2);

end